@@ -63,9 +63,7 @@ struct t_url_constant url_proxy_types[] =
     URL_DEF_CONST(PROXY, SOCKS4A),
     URL_DEF_CONST(PROXY, SOCKS5_HOSTNAME),
     URL_DEF_CONST(PROXY, HTTP_1_0),
-#if LIBCURL_VERSION_NUM >= 0x073400 /* 7.52.0 */
     URL_DEF_CONST(PROXY, HTTPS),
-#endif
     { NULL, 0 },
 };
 
@@ -131,12 +129,8 @@ struct t_url_constant url_auth[] =
     URL_DEF_CONST(AUTH, NTLM_WB),
 #endif
     URL_DEF_CONST(AUTH, NEGOTIATE),
-#if LIBCURL_VERSION_NUM >= 0x073700 /* 7.55.0 */
     URL_DEF_CONST(AUTH, GSSAPI),
-#endif
-#if LIBCURL_VERSION_NUM >= 0x073D00 /* 7.61.0 */
     URL_DEF_CONST(AUTH, BEARER),
-#endif
 #if LIBCURL_VERSION_NUM >= 0x074B00 /* 7.75.0 */
     URL_DEF_CONST(AUTH, AWS_SIGV4),
 #endif
@@ -165,12 +159,8 @@ struct t_url_constant url_http_version[] =
     URL_DEF_CONST(_HTTP_VERSION, 2_0),
     URL_DEF_CONST(_HTTP_VERSION, 2),
     URL_DEF_CONST(_HTTP_VERSION, 2TLS),
-#if LIBCURL_VERSION_NUM >= 0x073100 /* 7.49.0 */
     URL_DEF_CONST(_HTTP_VERSION, 2_PRIOR_KNOWLEDGE),
-#endif
-#if LIBCURL_VERSION_NUM >= 0x074200 /* 7.66.0 */
     URL_DEF_CONST(_HTTP_VERSION, 3),
-#endif
     { NULL, 0 },
 };
 
@@ -249,17 +239,13 @@ struct t_url_constant url_ssl_version[] =
     URL_DEF_CONST(_SSLVERSION, TLSv1_0),
     URL_DEF_CONST(_SSLVERSION, TLSv1_1),
     URL_DEF_CONST(_SSLVERSION, TLSv1_2),
-#if LIBCURL_VERSION_NUM >= 0x073400 /* 7.52.0 */
     URL_DEF_CONST(_SSLVERSION, TLSv1_3),
-#endif
-#if LIBCURL_VERSION_NUM >= 0x073600 /* 7.54.0 */
     URL_DEF_CONST(_SSLVERSION, MAX_DEFAULT),
     URL_DEF_CONST(_SSLVERSION, MAX_NONE),
     URL_DEF_CONST(_SSLVERSION, MAX_TLSv1_0),
     URL_DEF_CONST(_SSLVERSION, MAX_TLSv1_1),
     URL_DEF_CONST(_SSLVERSION, MAX_TLSv1_2),
     URL_DEF_CONST(_SSLVERSION, MAX_TLSv1_3),
-#endif
     { NULL, 0 },
 };
 
@@ -267,15 +253,11 @@ struct t_url_constant url_ssl_options[] =
 {
     URL_DEF_CONST(SSLOPT, ALLOW_BEAST),
     URL_DEF_CONST(SSLOPT, NO_REVOKE),
-#if LIBCURL_VERSION_NUM >= 0x073800 /* 7.56.0 */
     URL_DEF_CONST(SSLSET, NO_BACKENDS),
     URL_DEF_CONST(SSLSET, OK),
     URL_DEF_CONST(SSLSET, TOO_LATE),
     URL_DEF_CONST(SSLSET, UNKNOWN_BACKEND),
-#endif
-#if LIBCURL_VERSION_NUM >= 0x074400 /* 7.68.0 */
     URL_DEF_CONST(SSLOPT, NO_PARTIALCHAIN),
-#endif
 #if LIBCURL_VERSION_NUM >= 0x074600 /* 7.70.0 */
     URL_DEF_CONST(SSLOPT, REVOKE_BEST_EFFORT),
 #endif
@@ -306,9 +288,7 @@ struct t_url_constant url_ssh_auth[] =
     URL_DEF_CONST(SSH_AUTH, DEFAULT),
     URL_DEF_CONST(SSH_AUTH, ANY),
     URL_DEF_CONST(SSH_AUTH, AGENT),
-#if LIBCURL_VERSION_NUM >= 0x073A00 /* 7.58.0 */
     URL_DEF_CONST(SSH_AUTH, GSSAPI),
-#endif
     { NULL, 0 },
 };
 
@@ -366,9 +346,7 @@ struct t_url_option url_options[] =
      * error options
      */
     URL_DEF_OPTION(FAILONERROR, LONG, NULL),
-#if LIBCURL_VERSION_NUM >= 0x073300 /* 7.51.0 */
     URL_DEF_OPTION(KEEP_SENDING_ON_ERROR, LONG, NULL),
-#endif
 
     /*
      * network options
@@ -376,9 +354,7 @@ struct t_url_option url_options[] =
     URL_DEF_OPTION(PROXY, STRING, NULL),
     URL_DEF_OPTION(PROXYPORT, LONG, NULL),
     URL_DEF_OPTION(PORT, LONG, NULL),
-#if LIBCURL_VERSION_NUM >= 0x073400 /* 7.52.0 */
     URL_DEF_OPTION(PRE_PROXY, STRING, NULL),
-#endif
     URL_DEF_OPTION(HTTPPROXYTUNNEL, LONG, NULL),
     URL_DEF_OPTION(INTERFACE, STRING, NULL),
     URL_DEF_OPTION(DNS_CACHE_TIMEOUT, LONG, NULL),
@@ -400,28 +376,15 @@ struct t_url_option url_options[] =
     URL_DEF_OPTION(TCP_KEEPIDLE, LONG, NULL),
     URL_DEF_OPTION(TCP_KEEPINTVL, LONG, NULL),
     URL_DEF_OPTION(UNIX_SOCKET_PATH, STRING, NULL),
-#if LIBCURL_VERSION_NUM >= 0x073500 /* 7.53.0 */
     URL_DEF_OPTION(ABSTRACT_UNIX_SOCKET, STRING, NULL),
-#endif
     URL_DEF_OPTION(PATH_AS_IS, LONG, NULL),
     URL_DEF_OPTION(PROXY_SERVICE_NAME, STRING, NULL),
     URL_DEF_OPTION(SERVICE_NAME, STRING, NULL),
     URL_DEF_OPTION(DEFAULT_PROTOCOL, STRING, NULL),
-#if LIBCURL_VERSION_NUM < 0x073100 /* < 7.49.0 */
-    URL_DEF_OPTION(SOCKS5_GSSAPI_SERVICE, STRING, NULL),
-#endif
-#if LIBCURL_VERSION_NUM >= 0x073100 /* 7.49.0 */
     URL_DEF_OPTION(TCP_FASTOPEN, LONG, NULL),
-#endif
-#if LIBCURL_VERSION_NUM >= 0x073700 /* 7.55.0 */
     URL_DEF_OPTION(SOCKS5_AUTH, LONG, NULL),
-#endif
-#if LIBCURL_VERSION_NUM >= 0x073C00 /* 7.60.0 */
     URL_DEF_OPTION(HAPROXYPROTOCOL, LONG, NULL),
-#endif
-#if LIBCURL_VERSION_NUM >= 0x073E00 /* 7.62.0 */
     URL_DEF_OPTION(DOH_URL, STRING, NULL),
-#endif
 #if LIBCURL_VERSION_NUM >= 0x075500 /* 7.85.0 */
     URL_DEF_OPTION(PROTOCOLS_STR, STRING, NULL),
 #endif
@@ -445,16 +408,12 @@ struct t_url_option url_options[] =
     URL_DEF_OPTION(TLSAUTH_TYPE, MASK, url_authtype),
     URL_DEF_OPTION(TLSAUTH_USERNAME, STRING, NULL),
     URL_DEF_OPTION(TLSAUTH_PASSWORD, STRING, NULL),
-#if LIBCURL_VERSION_NUM >= 0x074200 /* 7.66.0 */
     URL_DEF_OPTION(SASL_AUTHZID, STRING, NULL),
-#endif
 
     URL_DEF_OPTION(SASL_IR, LONG, NULL),
     URL_DEF_OPTION(XOAUTH2_BEARER, STRING, NULL),
     URL_DEF_OPTION(LOGIN_OPTIONS, STRING, NULL),
-#if LIBCURL_VERSION_NUM >= 0x073D00 /* 7.61.0 */
     URL_DEF_OPTION(DISALLOW_USERNAME_IN_URL, LONG, NULL),
-#endif
 
     /*
      * HTTP options
@@ -490,15 +449,8 @@ struct t_url_option url_options[] =
     URL_DEF_OPTION(PROXYHEADER, LIST, NULL),
     URL_DEF_OPTION(PIPEWAIT, LONG, NULL),
     URL_DEF_OPTION(STREAM_WEIGHT, LONG, NULL),
-#if LIBCURL_VERSION_NUM >= 0x073700 /* 7.55.0 */
     URL_DEF_OPTION(REQUEST_TARGET, STRING, NULL),
-#endif
-#if LIBCURL_VERSION_NUM < 0x073800 /* < 7.56.0 */
-    URL_DEF_OPTION(HTTPPOST, LIST, NULL),
-#endif
-#if LIBCURL_VERSION_NUM >= 0x074000 /* 7.64.0 */
     URL_DEF_OPTION(HTTP09_ALLOWED, LONG, NULL),
-#endif
 #if LIBCURL_VERSION_NUM >= 0x074A00 /* 7.74.0 */
     URL_DEF_OPTION(HSTS, STRING, NULL),
     URL_DEF_OPTION(HSTS_CTRL, MASK, url_hsts),
@@ -521,9 +473,7 @@ struct t_url_option url_options[] =
      * TFTP options
      */
     URL_DEF_OPTION(TFTP_BLKSIZE, LONG, NULL),
-#if LIBCURL_VERSION_NUM >= 0x073000 /* 7.48.0 */
     URL_DEF_OPTION(TFTP_NO_OPTIONS, LONG, NULL),
-#endif
 
     /*
      * FTP options
@@ -580,12 +530,8 @@ struct t_url_option url_options[] =
     URL_DEF_OPTION(RESUME_FROM_LARGE, LONGLONG, NULL),
     URL_DEF_OPTION(INFILESIZE_LARGE, LONGLONG, NULL),
     URL_DEF_OPTION(MAXFILESIZE_LARGE, LONGLONG, NULL),
-#if LIBCURL_VERSION_NUM >= 0x073B00 /* 7.59.0 */
     URL_DEF_OPTION(TIMEVALUE_LARGE, LONGLONG, NULL),
-#endif
-#if LIBCURL_VERSION_NUM >= 0x073E00 /* 7.62.0 */
     URL_DEF_OPTION(UPLOAD_BUFFERSIZE, LONG, NULL),
-#endif
 #if LIBCURL_VERSION_NUM >= 0x075100 /* 7.81.0 */
     URL_DEF_OPTION(MIME_OPTIONS, MASK, url_mime),
 #endif
@@ -605,9 +551,7 @@ struct t_url_option url_options[] =
     URL_DEF_OPTION(MAX_RECV_SPEED_LARGE, LONGLONG, NULL),
     URL_DEF_OPTION(TIMEOUT_MS, LONG, NULL),
     URL_DEF_OPTION(CONNECTTIMEOUT_MS, LONG, NULL),
-#if LIBCURL_VERSION_NUM >= 0x074100 /* 7.65.0 */
     URL_DEF_OPTION(MAXAGE_CONN, LONG, NULL),
-#endif
     URL_DEF_OPTION(MAXCONNECTS, LONG, NULL),
     URL_DEF_OPTION(USE_SSL, LONG, url_use_ssl),
     URL_DEF_OPTION(RESOLVE, LIST, NULL),
@@ -616,18 +560,10 @@ struct t_url_option url_options[] =
     URL_DEF_OPTION(DNS_INTERFACE, STRING, NULL),
     URL_DEF_OPTION(DNS_LOCAL_IP4, STRING, NULL),
     URL_DEF_OPTION(DNS_LOCAL_IP6, STRING, NULL),
-#if LIBCURL_VERSION_NUM >= 0x073100 /* 7.49.0 */
     URL_DEF_OPTION(CONNECT_TO, LIST, NULL),
-#endif
-#if LIBCURL_VERSION_NUM >= 0x073B00 /* 7.59.0 */
     URL_DEF_OPTION(HAPPY_EYEBALLS_TIMEOUT_MS, LONG, NULL),
-#endif
-#if LIBCURL_VERSION_NUM >= 0x073C00 /* 7.60.0 */
     URL_DEF_OPTION(DNS_SHUFFLE_ADDRESSES, LONG, NULL),
-#endif
-#if LIBCURL_VERSION_NUM >= 0x073E00 /* 7.62.0 */
     URL_DEF_OPTION(UPKEEP_INTERVAL_MS, LONG, NULL),
-#endif
 #if LIBCURL_VERSION_NUM >= 0x075000 /* 7.80.0 */
     URL_DEF_OPTION(MAXLIFETIME_CONN, LONG, NULL),
 #endif
@@ -672,7 +608,6 @@ struct t_url_option url_options[] =
 #if LIBCURL_VERSION_NUM < 0x080F00 /* < 8.15.0 */
     URL_DEF_OPTION(SSL_FALSESTART, LONG, NULL),
 #endif
-#if LIBCURL_VERSION_NUM >= 0x073400 /* 7.52.0 */
     URL_DEF_OPTION(PROXY_CAINFO, STRING, NULL),
     URL_DEF_OPTION(PROXY_CAPATH, STRING, NULL),
     URL_DEF_OPTION(PROXY_CRLFILE, STRING, NULL),
@@ -690,11 +625,8 @@ struct t_url_option url_options[] =
     URL_DEF_OPTION(PROXY_TLSAUTH_PASSWORD, STRING, NULL),
     URL_DEF_OPTION(PROXY_TLSAUTH_TYPE, STRING, NULL),
     URL_DEF_OPTION(PROXY_TLSAUTH_USERNAME, STRING, NULL),
-#endif
-#if LIBCURL_VERSION_NUM >= 0x073D00 /* 7.61.0 */
     URL_DEF_OPTION(TLS13_CIPHERS, LIST, NULL),
     URL_DEF_OPTION(PROXY_TLS13_CIPHERS, LIST, NULL),
-#endif
 #if LIBCURL_VERSION_NUM >= 0x074700 /* 7.71.0 */
     URL_DEF_OPTION(PROXY_ISSUERCERT, STRING, NULL),
 #endif
@@ -718,9 +650,7 @@ struct t_url_option url_options[] =
     URL_DEF_OPTION(SSH_PRIVATE_KEYFILE, STRING, NULL),
     URL_DEF_OPTION(SSH_HOST_PUBLIC_KEY_MD5, STRING, NULL),
     URL_DEF_OPTION(SSH_KNOWNHOSTS, STRING, NULL),
-#if LIBCURL_VERSION_NUM >= 0x073800 /* 7.56.0 */
     URL_DEF_OPTION(SSH_COMPRESSION, LONG, NULL),
-#endif
 #if LIBCURL_VERSION_NUM >= 0x075000 /* 7.80.0 */
     URL_DEF_OPTION(SSH_HOST_PUBLIC_KEY_SHA256, STRING, NULL),
 #endif
@@ -1018,7 +948,7 @@ weeurl_set_proxy (CURL *curl, struct t_proxy *proxy)
 
     /* set proxy port */
     curl_easy_setopt (curl, CURLOPT_PROXYPORT,
-                      CONFIG_INTEGER(proxy->options[PROXY_OPTION_PORT]));
+                      (long)(CONFIG_INTEGER(proxy->options[PROXY_OPTION_PORT])));
 
     /* set username/password */
     if (CONFIG_STRING(proxy->options[PROXY_OPTION_USERNAME])
